Flash-X-Test
============

Installation
============

-  Use ``./setup develop`` for development mode

-  Or use ``./setup install`` to install package
   on your system

-  Or use ``pip install git+ssh://git@github.com/Flash-X/Flash-X-Test.git@main`` 

-  You are good to go. Now you can simply type ``flashxtest`` on your
   command line and it will be availabe, or you can import the Python API using
   ``import FlashXTest.api as flashxtest``

Usage
=====

``flashxtest --help`` and ``flashxtest [command] --help`` provide information on usage


Examples
========

See ``FlashXTest/example/example.suite`` for an example test suite
